﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DepPropDrawing
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            for(int i = -5; i <= 5; i++)
            {
                ACoefBox.Items.Add(i);
                BCoefBox.Items.Add(i * 10);
            }
            ACoefBox.SelectedItem = 0;
            BCoefBox.SelectedItem = 0;
            //DrawAxes(this);
        }

        private void MenuItem_Click(object sender, RoutedEventArgs e)
        {
            Application.Current.Shutdown();
        }

        private void ACoefBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ACoefProp = short.Parse(ACoefBox.SelectedItem.ToString());
        }

        private void BCoefBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            BCoefProperty = short.Parse(BCoefBox.SelectedItem.ToString());
        }


        public int ACoefProp
        {
            get { return (int)GetValue(ACoefPropProperty); }
            set { SetValue(ACoefPropProperty, value); }
        }

        // Using a DependencyProperty as the backing store for ACoefProp.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty ACoefPropProperty =
            DependencyProperty.Register("ACoefProp", typeof(int), typeof(MainWindow), new PropertyMetadata(0,ACoefPropertyChange));

        private static void ACoefPropertyChange(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            Draw((MainWindow)d);
        }



        public int BCoefProperty
        {
            get { return (int)GetValue(BCoefPropertyProperty); }
            set { SetValue(BCoefPropertyProperty, value); }
        }

        // Using a DependencyProperty as the backing store for BCoefProperty.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty BCoefPropertyProperty =
            DependencyProperty.Register("BCoefProperty", typeof(int), typeof(MainWindow), new PropertyMetadata(0,BCoefPropertyChange));

        private static void BCoefPropertyChange(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            Draw((MainWindow)d);
        }

        private static void Draw(MainWindow win)
        {
            win.DrawArea.Children.Clear();
            DrawAxes(win);
            DrawGraph(win);
        }

        private static void DrawAxes(MainWindow win)
        {
           // win.DrawArea.Children.Clear();
            Line axeX= new Line();
            Line axeY= new Line();
            axeX.Stroke = Brushes.Black;
            axeX.X1= 0; 
            axeX.X2= win.DrawArea.ActualWidth;
            axeX.Y1 = win.DrawArea.ActualHeight / 2;
            axeX.Y2 = win.DrawArea.ActualHeight / 2;
            axeY.Stroke = Brushes.Black;
            axeY.X1 = win.DrawArea.ActualWidth/2;
            axeY.X2 = win.DrawArea.ActualWidth/ 2;
            axeY.Y1 = 0;
            axeY.Y2 = win.DrawArea.ActualHeight;
            win.DrawArea.Children.Add(axeY);
            win.DrawArea.Children.Add(axeX);
        }

        private static void DrawGraph(MainWindow win)
        {
          //  win.DrawArea.Children.Clear();
            var a = win.ACoefProp;
            var b = win.BCoefProperty;

            Line graph = new Line();
            graph.Stroke = Brushes.Red;
            var startX = -win.DrawArea.ActualWidth / 2;
            var startY = a * startX + b;
            var endX = win.DrawArea.ActualWidth / 2;
            var endY = a * endX + b;
            graph.X1 = 0;
            graph.X2 = win.DrawArea.ActualWidth;
            graph.Y1 = win.DrawArea.ActualHeight / 2 - startY;
            graph.Y2 = win.DrawArea.ActualHeight / 2 - endY;
            graph.ClipToBounds = true;
            win.DrawArea.Children.Add(graph);
        }

        private void Window_Activated(object sender, EventArgs e)
        {
            DrawAxes(this);
        }
    }
}
